@@ -1,16 +1,14 @@
-# -*- coding: utf-8 -*-
 """Celery result backends for Django."""
 # :copyright: (c) 2016, Ask Solem.
 #             All rights reserved.
 # :license:   BSD (3 Clause), see LICENSE for more details.
 
-from __future__ import absolute_import, unicode_literals
-
 import re
-
 from collections import namedtuple
 
-__version__ = '2.0.0'
+import django
+
+__version__ = '2.4.0'
 __author__ = 'Asif Saif Uddin, Ask Solem'
 __contact__ = 'auvipy@gmai.com, ask@celeryproject.org'
 __homepage__ = 'https://github.com/celery/django-celery-results'
@@ -33,4 +31,5 @@ del(re)
 
 __all__ = []
 
-default_app_config = 'django_celery_results.apps.CeleryResultConfig'
+if django.VERSION < (3, 2):
+    default_app_config = 'django_celery_results.apps.CeleryResultConfig'
