@@ -1,9 +1,7 @@
 """Result Task Admin interface."""
-from __future__ import absolute_import, unicode_literals
-
-from django.contrib import admin
 
 from django.conf import settings
+from django.contrib import admin
 from django.utils.translation import gettext_lazy as _
 
 try:
@@ -12,7 +10,7 @@ except (AttributeError, KeyError):
     ALLOW_EDITS = False
     pass
 
-from .models import TaskResult
+from .models import GroupResult, TaskResult
 
 
 class TaskResultAdmin(admin.ModelAdmin):
@@ -20,10 +18,13 @@ class TaskResultAdmin(admin.ModelAdmin):
 
     model = TaskResult
     date_hierarchy = 'date_done'
-    list_display = ('task_id', 'task_name', 'date_done', 'status', 'worker')
-    list_filter = ('status', 'date_done', 'task_name', 'worker')
+    list_display = ('task_id', 'periodic_task_name', 'task_name', 'date_done',
+                    'status', 'worker')
+    list_filter = ('status', 'date_done', 'periodic_task_name', 'task_name',
+                   'worker')
     readonly_fields = ('date_created', 'date_done', 'result', 'meta')
-    search_fields = ('task_name', 'task_id', 'status')
+    search_fields = ('task_name', 'task_id', 'status', 'task_args',
+                     'task_kwargs')
     fieldsets = (
         (None, {
             'fields': (
@@ -59,9 +60,23 @@ class TaskResultAdmin(admin.ModelAdmin):
         if ALLOW_EDITS:
             return self.readonly_fields
         else:
-            return list(set(
-                [field.name for field in self.opts.local_fields]
-            ))
+            return list({
+                field.name for field in self.opts.local_fields
+            })
 
 
 admin.site.register(TaskResult, TaskResultAdmin)
+
+
+class GroupResultAdmin(admin.ModelAdmin):
+    """Admin-interface for results  of grouped tasks."""
+
+    model = GroupResult
+    date_hierarchy = 'date_done'
+    list_display = ('group_id', 'date_done')
+    list_filter = ('date_done',)
+    readonly_fields = ('date_created', 'date_done', 'result')
+    search_fields = ('group_id',)
+
+
+admin.site.register(GroupResult, GroupResultAdmin)
