@@ -1,7 +1,6 @@
 """Utilities."""
 # -- XXX This module must not use translation as that causes
 # -- a recursive loader import!
-from __future__ import absolute_import, unicode_literals
 
 from django.conf import settings
 from django.utils import timezone
@@ -16,3 +15,8 @@ def now():
         return now_localtime(timezone.now())
     else:
         return timezone.now()
+
+
+def raw_delete(queryset):
+    """Raw delete given queryset."""
+    return queryset._raw_delete(queryset.db)
