@@ -1,6 +1,3 @@
-# -*- coding: utf-8 -*-
-from __future__ import absolute_import, unicode_literals
-
 import os
 
 from sphinx_celery import conf
@@ -13,7 +10,7 @@ globals().update(conf.build_config(
     canonical_url='http://django-celery-results.readthedocs.io',
     webdomain='',
     github_project='celery/django-celery-results',
-    copyright='2009-2016',
+    copyright='2009-2022',
     django_settings='proj.settings',
     include_intersphinx={'python', 'sphinx', 'django', 'celery'},
     path_additions=[os.path.join(os.pardir, 't')],
